==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteStatusFluent<A extends HTTPRouteStatusFluent<A>> extends Fluent<A>{
  public A addToParents(Integer index,RouteParentStatus item);
  public A setToParents(Integer index,RouteParentStatus item);
  public A addToParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A addAllToParents(Collection<RouteParentStatus> items);
  public A removeFromParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A removeAllFromParents(Collection<RouteParentStatus> items);
  public A removeMatchingFromParents(Predicate<RouteParentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteParentStatus> getParents();
  public List<RouteParentStatus> buildParents();
  public RouteParentStatus buildParent(Integer index);
  public RouteParentStatus buildFirstParent();
  public RouteParentStatus buildLastParent();
  public RouteParentStatus buildMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public Boolean hasMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A withParents(List<RouteParentStatus> parents);
  public A withParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... parents);
  public Boolean hasParents();
  public HTTPRouteStatusFluent.ParentsNested<A> addNewParent();
  public HTTPRouteStatusFluent.ParentsNested<A> addNewParentLike(RouteParentStatus item);
  public HTTPRouteStatusFluent.ParentsNested<A> setNewParentLike(Integer index,RouteParentStatus item);
  public HTTPRouteStatusFluent.ParentsNested<A> editParent(Integer index);
  public HTTPRouteStatusFluent.ParentsNested<A> editFirstParent();
  public HTTPRouteStatusFluent.ParentsNested<A> editLastParent();
  public HTTPRouteStatusFluent.ParentsNested<A> editMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentsNested<N> extends Nested<N>,RouteParentStatusFluent<HTTPRouteStatusFluent.ParentsNested<N>>{
    public N and();
    public N endParent();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteStatusFluent<A extends HTTPRouteStatusFluent<A>> extends Fluent<A>{
  public A addToParents(int index,RouteParentStatus item);
  public A setToParents(int index,RouteParentStatus item);
  public A addToParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A addAllToParents(Collection<RouteParentStatus> items);
  public A removeFromParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... items);
  public A removeAllFromParents(Collection<RouteParentStatus> items);
  public A removeMatchingFromParents(Predicate<RouteParentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RouteParentStatus> getParents();
  public List<RouteParentStatus> buildParents();
  public RouteParentStatus buildParent(int index);
  public RouteParentStatus buildFirstParent();
  public RouteParentStatus buildLastParent();
  public RouteParentStatus buildMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public Boolean hasMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A withParents(List<RouteParentStatus> parents);
  public A withParents(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.RouteParentStatus... parents);
  public Boolean hasParents();
  public HTTPRouteStatusFluent.ParentsNested<A> addNewParent();
  public HTTPRouteStatusFluent.ParentsNested<A> addNewParentLike(RouteParentStatus item);
  public HTTPRouteStatusFluent.ParentsNested<A> setNewParentLike(int index,RouteParentStatus item);
  public HTTPRouteStatusFluent.ParentsNested<A> editParent(int index);
  public HTTPRouteStatusFluent.ParentsNested<A> editFirstParent();
  public HTTPRouteStatusFluent.ParentsNested<A> editLastParent();
  public HTTPRouteStatusFluent.ParentsNested<A> editMatchingParent(Predicate<RouteParentStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParentsNested<N> extends Nested<N>,RouteParentStatusFluent<HTTPRouteStatusFluent.ParentsNested<N>>{
    public N and();
    public N endParent();
    
  }
  
}
